@@ -100,7 +100,7 @@ class cmd(cmd_base):
 
     def __format(self):
         def check_and_format(option, format_func):
-            if self.sys_has_opt(option):
+            if self.get_opt(option):
                 args = [d for d in self.get_opt(
                     option).split(',') if len(d) > 0]
                 if len(args) == 0:
